==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/de/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Der Nutzer kann sich einloggen',
    'activated_disabled_help_text' => 'Sie können den Aktiverungsstatus für Ihren eigenen Account nicht ändern.',
    'assets_user'       => 'Assets zugewiesen an :name',
    'bulk_update_warn'	=> 'Sie sind dabei, die Eigenschaften von :user_count Benutzern zu bearbeiten. Bitte beachten Sie, dass Sie Ihre eigenen Benutzerattribute nicht über dieses Formular ändern können. Sie müssen Ihren eigenen Benutzer einzeln bearbeiten.',
    'bulk_update_help'	=> 'Hier können mehrere Benutzer gleichzeitig bearbeitet werden. Nur Felder ausfüllen, welche geändert werden sollen. Leere Felder werden nicht geändert.',
    'current_assets'    => 'Asset wurde an nachfolgenden Benutzer ausgegeben',
    'clone'             => 'Benutzer kopieren',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Benutzer bearbeiten',
    'filetype_info'     => 'Erlaubte Dateitypen sind png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, und rar.',
    'history_user'      => 'Historie von :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Klicken Sie hier, um sie wiederherzustellen.',
    'last_login'        => 'Letzte Anmeldung',
    'ldap_config_text'  => 'Die LDAP Konfigurations Einstellungen finden Sie hier Admin -> Einstellungen. Der (optional) wählbare Standort wird für alle importierten Benutzer gesetzt.',
    'print_assigned'    => 'Alles zugewiesene drucken',
    'software_user'     => 'Software herausgegeben an :name',
    'send_email_help'   => 'Sie müssen eine E-Mail-Adresse angeben, um dem Benutzer Zugangsdaten zu zusenden. Das Versenden von Zugangsdaten ist nur bei der Erstellung eines Benutzers möglich. Passwörter werden in einem Einweg-Hash gespeichert und können danach nicht mehr ausgelesen werden.',
    'view_user'         => 'Benutzer :name ansehen',
    'usercsv'           => 'CSV Datei',
    'two_factor_admin_optin_help' => 'Ihre aktuellen Administrator-Einstellungen erlauben die selektive Durchführung der zwei-Faktor-Authentifizierung.  ',
    'two_factor_enrolled' => '2FA Gerät eingeschrieben ',
    'two_factor_active'   => '2FA aktiv ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/de/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Der Nutzer kann sich einloggen',
    'activated_disabled_help_text' => 'Sie können den Aktiverungsstatus für Ihren eigenen Account nicht ändern.',
    'assets_user'       => 'Assets zugewiesen an :name',
    'bulk_update_warn'	=> 'Sie sind dabei, die Eigenschaften von :user_count Benutzern zu bearbeiten. Bitte beachten Sie, dass Sie Ihre eigenen Benutzerattribute nicht über dieses Formular ändern können. Sie müssen Ihren eigenen Benutzer einzeln bearbeiten.',
    'bulk_update_help'	=> 'Hier können mehrere Benutzer gleichzeitig bearbeitet werden. Nur Felder ausfüllen, welche geändert werden sollen. Leere Felder werden nicht geändert.',
    'current_assets'    => 'Asset wurde an nachfolgenden Benutzer ausgegeben',
    'clone'             => 'Benutzer kopieren',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Benutzer bearbeiten',
    'filetype_info'     => 'Erlaubte Dateitypen sind png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, und rar.',
    'history_user'      => 'Historie von :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klicken Sie hier, um sie wiederherzustellen.',
    'last_login'        => 'Letzte Anmeldung',
    'ldap_config_text'  => 'Die LDAP Konfigurations Einstellungen finden Sie hier Admin -> Einstellungen. Der (optional) wählbare Standort wird für alle importierten Benutzer gesetzt.',
    'print_assigned'    => 'Alles zugewiesene drucken',
    'software_user'     => 'Software herausgegeben an :name',
    'send_email_help'   => 'Sie müssen eine E-Mail-Adresse angeben, um dem Benutzer Zugangsdaten zu zusenden. Das Versenden von Zugangsdaten ist nur bei der Erstellung eines Benutzers möglich. Passwörter werden in einem Einweg-Hash gespeichert und können danach nicht mehr ausgelesen werden.',
    'view_user'         => 'Benutzer :name ansehen',
    'usercsv'           => 'CSV Datei',
    'two_factor_admin_optin_help' => 'Ihre aktuellen Administrator-Einstellungen erlauben die selektive Durchführung der zwei-Faktor-Authentifizierung.  ',
    'two_factor_enrolled' => '2FA Gerät eingeschrieben ',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'Benutzer ist deaktiviert',
    'activation_status_warning' => 'Aktivierungsstatus nicht ändern',
    'group_memberships_helpblock' => 'Nur Superadministratoren können Gruppenmitgliedschaften bearbeiten.',
    'superadmin_permission_warning' => 'Nur Superadmins dürfen einem Benutzer Superadmin Zugriff gewähren.',
    'admin_permission_warning' => 'Nur Benutzer mit Administratorrechten oder höher dürfen einem Benutzer Administratorzugriff gewähren.',
    'remove_group_memberships' => 'Gruppenmitgliedschaften entfernen',
    'warning_deletion' => 'WARNUNG:',
    'warning_deletion_information' => 'Sie sind dabei, die :count unten aufgelisteten Benutzer zu löschen. Super-Admin-Namen sind rot markiert.',
    'update_user_asssets_status' => 'Alle Assets für diese Benutzer auf diesen Status aktualisieren',
    'checkin_user_properties' => 'Alle diesen Benutzern zugeordneten Objekte zurücknehmen',
];
